==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
var WebSliderLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSliderLabelDescriptionMetadata, _super);
    function WebSliderLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderLabelDescriptionMetadata.b = function (a) {
        if (WebSliderLabelDescriptionMetadata.a == null) {
            WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
        }
        if (a.k(WebSliderLabelDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderLabel");
        a.item("__tagNameWC", "String:igc-slider-label");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebSliderLabelDescriptionMetadata.d = function (a) {
        WebSliderLabelDescriptionMetadata.b(a);
        a.ac("WebSliderLabel", function () { return new WebSliderLabelDescription(); });
        a.ab("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
}(Base));
export { WebSliderLabelDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
var WebSliderLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderLabelDescriptionMetadata, _super);
    function WebSliderLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderLabelDescriptionMetadata.b = function (a) {
        if (WebSliderLabelDescriptionMetadata.a == null) {
            WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
        }
        if (a.k(WebSliderLabelDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderLabel");
        a.item("__tagNameWC", "String:igc-slider-label");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebSliderLabelDescriptionMetadata.d = function (a) {
        WebSliderLabelDescriptionMetadata.b(a);
        a.ae("WebSliderLabel", function () { return new WebSliderLabelDescription(); });
        a.ad("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
}(Base));
export { WebSliderLabelDescriptionMetadata };
